#
# spec file for package ruby
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ruby
Version:        3.2
Release:        1.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         README
Url:            http://www.ruby-lang.org/
Summary:        An Interpreted Object-Oriented Scripting Language
License:        MIT
Group:          Development/Languages/Ruby
BuildRequires:  ruby%{version}-devel
#!BuildIgnore:  ruby
#!BuildIgnore:  rubygem-gem2rpm
%requires_ge ruby%{version}
Provides:       rubygems = 1.8.15
Obsoletes:      rubygems < 1.8.15

%description
Ruby is an interpreted scripting language for quick and easy
object-oriented programming.  It has many features for processing text
files and performing system management tasks (as in Perl).  It is
simple, straight-forward, and extensible.

* Ruby features:

- Simple Syntax

- *Normal* Object-Oriented features (class, method calls, for
   example)

- *Advanced* Object-Oriented features(Mix-in, Singleton-method, for
   example)

- Operator Overloading

- Exception Handling

- Iterators and Closures

- Garbage Collection

- Dynamic Loading of Object Files (on some architectures)

- Highly Portable (works on many UNIX machines; DOS, Windows, Mac,
BeOS, and more)

%package devel
Summary:        Development files to link against Ruby
Group:          Development/Languages/Ruby
Requires:       %{name}
%requires_ge    ruby%{version}-devel

%description devel
Development files to link against Ruby.

%prep

%build

%install
install -D -m 0644 %{S:0} %{buildroot}/usr/share/doc/packages/ruby/README
install -D -m 0644 %{S:0} %{buildroot}/usr/share/doc/packages/ruby-devel/README

%files
%defattr(-,root,root)
%doc /usr/share/doc/packages/ruby/

%files devel
%defattr(-,root,root)
%doc /usr/share/doc/packages/ruby-devel/

%changelog
* Tue Dec  6 2022 Marcus Rueckert <mrueckert@suse.de>
- switch the default ruby to 3.2
* Thu Dec 30 2021 Marcus Rueckert <mrueckert@suse.de>
- switch the default ruby to 3.1
* Sun Oct 25 2020 Marcus Rueckert <mrueckert@suse.de>
- switch the default ruby to 3.0
* Mon Feb 17 2020 Marcus Rueckert <mrueckert@suse.de>
- switch the default ruby to 2.7
* Tue Jan 29 2019 Stephan Kulow <coolo@suse.com>
- switch the default ruby to 2.6
* Tue Nov 14 2017 behlert@suse.de
- switch the default ruby to 2.5
* Tue Jul 11 2017 coolo@suse.com
- switch the default ruby to 2.4
* Wed Feb 18 2015 coolo@suse.com
- bump version
* Wed Sep 10 2014 mrueckert@suse.de
- to make it easier to migrate from the old scheme to the new
  scheme BuildIgnore: ruby aswell
* Tue Sep  9 2014 mrueckert@suse.de
- cleaned up buildrequires/requires and added buildignore for rubygem-gem2rpm
* Mon Jun 23 2014 mrueckert@suse.de
- remove obsolete expand line
* Fri Jun 20 2014 mrueckert@suse.de
- remove the provides to avoid have choice
* Sat Jun 14 2014 mrueckert@suse.de
- migrated to just plain wrapper packages
- patches moved to ruby2.1 package:
  rubygems-1.5.0_buildroot.patch
  ruby-1.9.2p290_tcl_no_stupid_rpaths.patch
  drop_content_size_check_in_xmlrpc.patch
  ruby19-export_init_prelude.patch
* Fri May 16 2014 kkaempf@suse.com
- Update to 2.1.2
  - fix for a regression of Hash#reject in Ruby 2.1.1
  - support for build with Readline-6.3 (see Bug #9578)
  - updated bundled version of libyaml with psych
  - some bug fixes.
* Sun Mar  2 2014 kkaempf@suse.com
- make api_version explicit in spec
- adapt versions of embedded gems
* Fri Feb 28 2014 adrian@suse.de
- use api version 2.1.0 again to avoid dependency breakages
* Fri Feb 28 2014 kkaempf@suse.com
- Update to 2.1.1
  Speedup and bugfixes (upstream bug ids):
  - rubygems 2.2.2 (#9489)
  - fix segfault at unpacking modified String (#9478)
  - Struct#send(:setter=, rhs) does not return rhs (#9470)
  - Array#uniq behavior change (#9470)
  - Timeout behavior change (#9470)
  - Hash lookup with #hash and #eql broken (#9470)
  - bigdecimal division issue (#9470)
  - SizedQueue not working (#9470)
  - BidDecimal division (#9316)
  - fix 'gem install --ignore-dependencies' for remote gems  (#9282)
  - Array#to_h should not ignore badly formed elements (#9270)
  - Method#arity for keyword arguments (#8072)
* Sat Feb 15 2014 kkaempf@suse.com
- add internal.h to ruby-devel-extra
* Mon Feb 10 2014 kkaempf@suse.com
- Don't require rpm-with-ruby-provide-hook on SLE11.
  It's not a runtime requirement but a build-time requirement for
  rubygems in SLE11. Buildservice will take care of that.
* Fri Feb  7 2014 coolo@suse.com
- reintroduce update-alternatives for rake, rdoc and ri as those
  can come from more uptodate gems
* Sat Feb  1 2014 coolo@suse.com
- readd old macros - for now at least
* Fri Jan 31 2014 kkaempf@suse.com
- generate provides for embedded rubygems
* Thu Jan 30 2014 kkaempf@suse.com
- merged ruby-common
* Sun Jan 19 2014 kkaempf@suse.com
- new package split - only single Ruby version installable
  ruby - binary
  libruby2_1-2_0 - ruby runtime library
  ruby-stdlib - ruby standard library
  ruby-doc - ruby documentation
  ruby-devel - ruby development
* Sun Jan 19 2014 kkaempf@suse.com
- revert the ruby split (ruby - ruby21)
  rename ruby21 to ruby, integrate 'ruby' and 'ruby-common'
* Thu Jan  9 2014 jreidinger@suse.com
- remove part of rubygems1.5 patch that modify mkmf which is
  already fixed upstream
* Wed Jan  8 2014 kkaempf@suse.com
- fix rb_arch in spec: append -gnu
- fix native gem builds: create gem native extensions dir
* Mon Jan  6 2014 coolo@suse.com
- initial version for ruby 2.1.0 - changes to Ruby 2.0:
  VM (method cache)
  RGenGC (See ko1’s RubyKaigi presentation and RubyConf 2013 presentation)
  refinements #8481 #8571
  syntax changes
  Rational/Complex Literal #8430
  def’s return value #3753
  Bignum
  use GMP #8796
  String#scrub #8414
  Socket.getifaddrs #8368
  RDoc 4.1.0 and RubyGems 2.2.0
  “literal”.freeze is now optimized #9042
  add Exception#cause #8257
  update libraries like BigDecimal, JSON, NKF, Rake, RubyGems, and RDoc
  remove curses #8584
- initial patches:
  drop_content_size_check_in_xmlrpc.patch
  ruby-1.9.2p290_tcl_no_stupid_rpaths.patch
  ruby19-export_init_prelude.patch
  rubygems-1.5.0_buildroot.patch
